#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define base_name cloud-netconfig

%if "ec2" == ""
%define flavor_suffix %nil
%define csp_string None
ExclusiveArch:  do-not-build
%endif
%if "ec2" == "azure"
%define flavor_suffix -azure
%define csp_string Microsoft Azure
%endif
%if "ec2" == "ec2"
%define flavor_suffix -ec2
%define csp_string Amazon EC2
%endif
%if "ec2" == "gce"
%define flavor_suffix -gce
%define csp_string Google Compute Engine
%endif

%if ! %{defined _distconfdir}
%define _distconfdir %{_sysconfdir}
%define no_dist_conf 1
%endif

Name:           %{base_name}%{flavor_suffix}
Version:        1.7
Release:        150000.25.8.1
License:        GPL-3.0-or-later
Summary:        Network configuration scripts for %{csp_string}
URL:            https://github.com/SUSE-Enceladus/cloud-netconfig
Group:          System/Management
Source0:        %{base_name}-%{version}.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%if 0%{?suse_version} == 1110
BuildRequires:  sysconfig
Requires:       sysconfig
%define _udevrulesdir %{_sysconfdir}/udev/rules.d
%else
BuildRequires:  sysconfig-netconfig
Requires:       sysconfig-netconfig
%endif
BuildRequires:  pkgconfig(udev)
%if 0%{?sle_version} > 150100
BuildRequires:  NetworkManager
%endif
Requires:       curl
Requires:       udev
%if 0%{?sles_version} == 11
# RPM in SLES 11 does not support self conflict, use otherproviders()
# workaround
Provides:       cloud-netconfig
Conflicts:      otherproviders(cloud-netconfig)
%else
Provides:       cloud-netconfig
Conflicts:      cloud-netconfig
%endif
%{?systemd_requires}
%define _scriptdir %{_libexecdir}/cloud-netconfig
%if 0%{?suse_version} > 1550
%define _netconfigdir %{_libexecdir}/netconfig.d
%else
%define _netconfigdir %{_sysconfdir}/netconfig.d
%endif

%description -n %{base_name}%{flavor_suffix}
This package contains scripts for automatically configuring network interfaces
in %{csp_string} with full support for hotplug.

%if 0%{?sle_version} > 150100
%package -n %{base_name}-nm
Summary:        Network configuration scripts for %{csp_string}
Group:          System/Management
Requires:       NetworkManager
Requires:       cloud-netconfig

%description -n %{base_name}-nm
Dispatch script for NetworkManager that automatically runs cloud-netconfig.
%endif

%prep
%setup -q -n %{base_name}-%{version}

%build

%install
make install%{flavor_suffix} \
  DESTDIR=%{buildroot} \
  PREFIX=%{_usr} \
  SYSCONFDIR=%{_sysconfdir} \
  DISTCONFDIR=%{_distconfdir} \
  SCRIPTDIR=%{_scriptdir} \
  UDEVRULESDIR=%{_udevrulesdir} \
  UNITDIR=%{_unitdir} \
  NETCONFIGDIR=%{_netconfigdir}

# Disable persistent net generator from udev-persistent-ifnames as
# it does not work for xen interfaces. This will likely produce a warning.
%if 0%{?suse_version} >= 1315
mkdir -p %{buildroot}/%{_sysconfdir}/udev/rules.d
ln -s /dev/null %{buildroot}/%{_sysconfdir}/udev/rules.d/75-persistent-net-generator.rules
%endif

%if 0%{?sle_version} <= 150100
rm -r %{buildroot}/usr/lib/NetworkManager
%endif

%files -n %{base_name}%{flavor_suffix}
%defattr(-,root,root)
%{_scriptdir}
%if %{defined no_config}
%config(noreplace) %{_distconfdir}/default/cloud-netconfig
%else
%{_distconfdir}/default/cloud-netconfig
%endif
%{_netconfigdir}
%if 0%{?suse_version} >= 1315
%{_sysconfdir}/udev/rules.d
%endif
%{_udevrulesdir}/*
%{_unitdir}/*
%doc README.md
%license LICENSE

%if 0%{?sle_version} > 150100
%files -n %{base_name}-nm
/usr/lib/NetworkManager/dispatcher.d
%endif

%pre
%service_add_pre %{base_name}.service %{base_name}.timer

%post
%service_add_post %{base_name}.service %{base_name}.timer

%preun
%service_del_preun %{base_name}.service %{base_name}.timer

%postun
%service_del_postun %{base_name}.service %{base_name}.timer

%changelog
* Fri Dec 16 2022 jgleissner@suse.com
- Update to version 1.7:
  + Overhaul policy routing setup (issue #19)
  + Support alias IPv4 ranges (issue #14)
  + Add support for NetworkManager (bsc#1204549)
  + Remove dependency on netconfig
  + Install into libexec directory
  + Clear stale ifcfg files for accelerated NICs (bsc#1199853)
  + More debug messages
  + Documentation update
* Sun Sep 18 2022 suse-beta@cboltz.de
- /etc/netconfig.d/ moved to /usr/libexec/netconfig/netconfig.d/ in
  Tumbleweed, update path (poo#116221)
* Fri Aug 27 2021 jgleissner@suse.com
- Update to version 1.6:
  + Ignore proxy when accessing metadata (bsc#1187939)
  + Print warning in case metadata is not accessible
  + Documentation update
* Thu Nov  5 2020 jgleissner@suse.com
- Update to version 1.5:
  + Add support for GCE (bsc#1159460, bsc#1178486)
  + Improve default gateway determination
* Tue Feb  4 2020 jgleissner@suse.com
- Update to version 1.4:
  + copy routes from default routing table (bsc#1162705, bsc#1162707)
  + make CLOUD_NETCONFIG_MANAGE default configurable
* Mon Feb  3 2020 dimstar@opensuse.org
- BuildRequire pkgconfig(udev) instead of udev: allow OBS to
  shortcut through the -mini flavors.
* Thu Nov 28 2019 jgleissner@suse.com
- Removed obsolete Group tag from spec file
* Tue Nov 26 2019 jgleissner@suse.com
- Update to version 1.3:
  + Fix IPv4 address handling on secondary NICs in Azure
* Tue Nov 26 2019 jgleissner@suse.com
- Update to version 1.2:
  + support AWS IMDSv2 token
* Thu Nov 21 2019 jgleissner@suse.com
- Update to version 1.1
  + fix use of GATEWAY variable (bsc#1157117, bsc#1157190)
  + remove secondary IPv4 address only when added by cloud-netconfig
    (bsc#1144282)
  + simplify routing setup for single NIC systems (partly fixes
    bsc#1135592)
* Thu May 16 2019 jgleissner@suse.com
- Update to version 1.0:
  + pause and retry if API call throttling is detected in Azure
    (bsc#1135257 bsc#1135263)
* Thu Jan 31 2019 jgleissner@suse.com
- Update to version 0.9:
  + run cloud-netconfig periodically (bsc#1118783 bsc#1122013)
  + do not treat eth0 special wrt routing policies (bsc#1123008)
  + reduce timeout on metadata read (bsc#1112822)
* Fri Jun  1 2018 jgleissner@suse.com
- Update to version 0.7:
  + no persistent interface names in Azure (bsc#1095485)
* Wed Jan 17 2018 jgleissner@suse.com
- Added dependency on curl
- Use otherproviders() only on SLES 11 builds
* Fri Jan 12 2018 jgleissner@suse.com
- Remove dependency on udev-persistent-ifnames (bsc#1075484)
* Thu Nov  9 2017 adrian.glaubitz@suse.com
- Add missing Provides/Conflicts statements to spec file
* Fri Oct 13 2017 jgleissner@suse.com
- Prepare for SLE11 submission (bsc#1063292)
* Fri Oct 13 2017 jgleissner@suse.com
- Update to version 0.6:
  + Use tested and supported metadata API versions
* Wed Oct 11 2017 rjschwei@suse.com
- Update to version 0.5
  + New API version for Azure metadata server
  + Wait for the metadata server in EC2
* Tue Oct 10 2017 jgleissner@suse.com
- Update to version 0.4:
  Do not touch VF interfaces in Azure (bsc#1055553)
- Prepare for SLE submission (FATE#323820, bsc#1027212)
* Thu Sep  7 2017 jgleissner@suse.com
- Added conflict tags
- Fix requires for non-Leap platforms
* Mon Aug 14 2017 jgleissner@suse.com
- Initial version 0.3
